#include <stdio.h>
#include <stdlib.h>

#include "fileoutput.h"

unsigned char colors0[256],colors1[256];

struct _bitmap_file bmp_file_in0, bmp_file_in1;
struct _bitmap_info bmp_info_in0, bmp_info_in1;

int main(int argc, char *argv[])
{
FILE *in0,*in1,*out;
int c,t;

  printf("\nAnaglyph generator - Copyright 2004 Michael Kohn\n");

  if (argc!=4)
  {
    printf("Usage: anaglyph <left image.bmp> <right image.bmp> <output image.bmp>\n\n");
    exit(0);
  }

  in0=fopen(argv[1],"rb");
  if (in0==0)
  {
    printf("Could not open input file: %s\n",argv[1]);
    exit(0);
  }

  in1=fopen(argv[2],"rb");
  if (in1==0)
  {
    printf("Could not open input file: %s\n",argv[2]);
    fclose(in0);
    exit(0);
  }

  out=fopen(argv[3],"wb");
  if (out==0)
  {
    printf("Could not open output file: %s\n",argv[3]);
    fclose(in0);
    fclose(in1);
    exit(0);
  }

  read_bitmap_file(in0,&bmp_file_in0);
  read_bitmap_file(in1,&bmp_file_in1);

  read_bitmap_info(in0,&bmp_info_in0);
  read_bitmap_info(in1,&bmp_info_in1);

  if (bmp_info_in0.biWidth!=bmp_info_in1.biWidth ||
      bmp_info_in0.biHeight!=bmp_info_in1.biHeight ||
      bmp_info_in0.biClrImportant!=bmp_info_in1.biClrImportant ||
      bmp_info_in0.biCompression!=bmp_info_in1.biCompression)
  {
    printf("Input BMP's are incompatible.\nThey must have the same width, height, number of colors, and compression.\n");
  }
    else
  if (bmp_info_in0.biCompression==2 || bmp_info_in0.biCompression==1)
  {
    printf("RLE8 and RLE4 compression is not supported at this time.\n");
  }
    else
  {
#ifdef DEBUG
    display_bmp_info(0, &bmp_file_in0, &bmp_info_in0);
    display_bmp_info(1, &bmp_file_in1, &bmp_info_in1);
#endif

    for (t=0; t<bmp_info_in0.biClrImportant; t++)
    {
      c=(getc(in0)+getc(in0)+getc(in0))/3;
      getc(in0);
      colors0[t]=c;
    }

    for (t=0; t<bmp_info_in1.biClrImportant; t++)
    {
      c=(getc(in1)+getc(in1)+getc(in1))/3;
      getc(in1);
      colors1[t]=c;
    }

    fseek(in0,bmp_file_in0.bfOffs,0);
    fseek(in1,bmp_file_in1.bfOffs,0);
    write_bmp_header(out,bmp_info_in0.biWidth,bmp_info_in0.biHeight);

/*
    for (t=0; t<bmp_info_in0.biHeight; t++)
    {
      for (c=0; c<bmp_info_in0.biWidth; c++)
      {
        write_bmp_pixel(out,0,150);
      }
    }
*/

    if (bmp_info_in0.biCompression==0)
    {
      raw_uncompressed(out,in0,in1,&bmp_info_in0);
    }
      else
    if (bmp_info_in0.biCompression==1)
    {
      /* raw_compressed8(out,in0,in1,&bmp_info_in0); */
    }
      else
    {
      printf("This type of compression is not supported at this time.\n");
    }


  }

  fclose(in0);
  fclose(in1);
  fclose(out);

  printf("\n");

  return 0;
}

